@@ -6,6 +6,9 @@
         self.payload = ''
         self.image_url = ''
 
+        self.mid = ''
+        self.text = ''
+
         return super().__init__(**kwargs)
 
     def set_content_type(self, content_type):
@@ -18,4 +21,10 @@
         self.payload = payload
 
     def set_image_url(self, image_url):
-        self.image_url = image_url
\ No newline at end of file
+        self.image_url = image_url
+
+    
+    def json_to_var(self, json):
+        self.mid = json['mid']
+        self.text = json['text']
+        self.payload = json['quick_reply']['payload']
\ No newline at end of file
